@@ -3,10 +3,7 @@
 use rayon::prelude::*;
 use serde::Serialize;
 use serde_pickle as pkl;
-use std::error::Error;
-use std::ffi::CString;
-use std::fmt;
-use std::{fs::File, path::Path};
+use std::{error::Error, ffi::CString, fmt, fs::File, path::Path};
 
 //include!("bindings.rs");
 
@@ -104,6 +101,10 @@ impl Delaunay {
             edges: None,
         }
     }
+    /// Returns the `Delaunay` builder
+    pub fn builder() -> Builder {
+        Builder::new()
+    }
     /// Returns the number of vertices
     pub fn n_vertices(&self) -> usize {
         self.points.len() / 2
@@ -151,7 +152,20 @@ impl Delaunay {
         self.triangle_iter()
             .map(move |t| t.iter().map(|&i| (x[i], y[i])).collect::<Vec<(f64, f64)>>())
     }
-
+    /// Removes triangles inside a circle of given `radius` centered on `Some(origin)`
+    pub fn filter_within_circle(&mut self, radius: f64, origin: Option<(f64, f64)>) -> &mut Self {
+        let x = self.x();
+        let y = self.y();
+        let (x0, y0) = origin.unwrap_or_default();
+        self.triangles = self
+            .triangles
+            .chunks(3)
+            .filter(move |t| t.iter().all(|&i| (x[i] - x0).hypot(y[i] - y0) > radius))
+            .flatten()
+            .cloned()
+            .collect();
+        self
+    }
     /// Returns the triangle areas
     pub fn triangle_areas(&self) -> Vec<f64> {
         let vertices: Vec<Vec<f64>> = self.vertex_iter().map(|x| x.to_vec()).collect();
